DROP TABLE IF EXISTS meas_engine_model;
CREATE TABLE meas_engine_model(
    `id` INT NOT NULL  COMMENT '编号' ,
    `model` VARCHAR(50) NOT NULL  COMMENT '发动机型号' ,
    `geometry_files` VARCHAR(255)   COMMENT '几何模型文件' ,
    `geometry_image` VARCHAR(255)   COMMENT '几何模型图片' ,
    `create_by` VARCHAR(32)   COMMENT '创建人' ,
    `create_time` DATETIME   COMMENT '创建时间' ,
    `update_by` VARCHAR(32)   COMMENT '更新人' ,
    `update_time` DATETIME   COMMENT '更新时间' ,
    PRIMARY KEY (id)
)  COMMENT = '发动机型号表';

DROP TABLE IF EXISTS meas_batch;
CREATE TABLE meas_batch(
    `id` INT AUTO_INCREMENT COMMENT '编号' ,
    `engine_id` INT NOT NULL  COMMENT '发动机型号ID' ,
    `measurement_batch` VARCHAR(255) NOT NULL  COMMENT '测量批次' ,
    `create_by` VARCHAR(32)   COMMENT '创建人' ,
    `create_time` DATETIME   COMMENT '创建时间' ,
    `update_by` VARCHAR(32)   COMMENT '更新人' ,
    `update_time` DATETIME   COMMENT '更新时间' ,
    PRIMARY KEY (id)
)  COMMENT = '测量批次表';

DROP TABLE IF EXISTS meas_env_data;
CREATE TABLE meas_env_data(
    `id` INT AUTO_INCREMENT COMMENT '编号' ,
    `measurement_batch_id` INT NOT NULL  COMMENT '测量批次id' ,
    `engine_status` VARCHAR(20) NOT NULL  COMMENT '发动机状态' ,
    `angle` VARCHAR(255)   COMMENT '角度' ,
    `turbine_post_temp` DECIMAL(8,2) NOT NULL  COMMENT '涡轮后温度' ,
    `test_distance` DECIMAL(8,2)   COMMENT '测试距离' ,
    `time` VARCHAR(255) NOT NULL  COMMENT '时间' ,
    `location` VARCHAR(50) NOT NULL  COMMENT '地点' ,
    `atmos_press` DECIMAL(8,2)   COMMENT '大气压' ,
    `temperature` DECIMAL(8,2)   COMMENT '温度' ,
    `wind_speed` DECIMAL(8,2)   COMMENT '风速' ,
    `humidity` DECIMAL(8,2)   COMMENT '湿度' ,
    `concentration` DECIMAL(8,2)   COMMENT '浓度' ,
    `create_by` VARCHAR(32)   COMMENT '创建人' ,
    `create_time` DATETIME   COMMENT '创建时间' ,
    `update_by` VARCHAR(32)   COMMENT '更新人' ,
    `update_time` DATETIME   COMMENT '更新时间' ,
    PRIMARY KEY (id)
)  COMMENT = '测量环境数据表';

DROP TABLE IF EXISTS meas_spectral_radiation;
CREATE TABLE meas_spectral_radiation(
    `id` INT AUTO_INCREMENT COMMENT '编号' ,
    `measurement_batch_id` INT NOT NULL  COMMENT '测量批次id' ,
    `model` VARCHAR(50) NOT NULL  COMMENT '型号' ,
    `lens_f_view` DECIMAL(8,2) NOT NULL  COMMENT '镜头视场角' ,
    `gain` INT NOT NULL  COMMENT '增益' ,
    `background_data` VARCHAR(255)   COMMENT '背景数据' ,
    `cal_temp` INT   COMMENT '标定温度' ,
    `cal_curve` VARCHAR(255)   COMMENT '标定曲线' ,
    `raw_data` VARCHAR(255)   COMMENT '原始数据' ,
    `radiance_1` VARCHAR(255)   COMMENT '辐射亮度（3~5μm）' ,
    `radiance_2` VARCHAR(255)   COMMENT '辐射亮度（8~14μm）' ,
    `create_by` VARCHAR(32)   COMMENT '创建人' ,
    `create_time` DATETIME   COMMENT '创建时间' ,
    `update_by` VARCHAR(32)   COMMENT '更新人' ,
    `update_time` DATETIME   COMMENT '更新时间' ,
    PRIMARY KEY (id)
)  COMMENT = '光谱辐射表';

DROP TABLE IF EXISTS meas_thermal_imager_test_data;
CREATE TABLE meas_thermal_imager_test_data(
    `id` INT AUTO_INCREMENT COMMENT '编号' ,
    `measurement_batch_id` INT   COMMENT '测量批次id' ,
    `model` VARCHAR(50)   COMMENT '型号' ,
    `lens_f_view` VARCHAR(255)   COMMENT '镜头视场角' ,
    `filter_no` VARCHAR(255)   COMMENT '滤镜编号' ,
    `fps` VARCHAR(255)   COMMENT '帧率' ,
    `spectral_band` VARCHAR(255)   COMMENT '波段' ,
    `integration_time` INT   COMMENT '积分时间' ,
    `temp_cal` VARCHAR(255)   COMMENT '温度标定' ,
    `radiance` VARCHAR(255)   COMMENT '辐射亮度' ,
    `rad_illumination` VARCHAR(255)   COMMENT '辐射照度' ,
    `rad_temp` VARCHAR(255)   COMMENT '辐射温度' ,
    `create_by` VARCHAR(32)   COMMENT '创建人' ,
    `create_time` DATETIME   COMMENT '创建时间' ,
    `update_by` VARCHAR(32)   COMMENT '更新人' ,
    `update_time` DATETIME   COMMENT '更新时间' ,
    PRIMARY KEY (id)
)  COMMENT = '热像仪测试数据表';

DROP TABLE IF EXISTS meas_transmission_rate;
CREATE TABLE meas_transmission_rate(
    `id` INT AUTO_INCREMENT COMMENT '编号' ,
    `measurement_batch_id` INT NOT NULL  COMMENT '测量批次id' ,
    `raw_data` VARCHAR(255)   COMMENT '原始数据' ,
    `curve_1` VARCHAR(255)   COMMENT '透过率曲线3~5μm' ,
    `curve_2` VARCHAR(255)   COMMENT '透过率曲线8~14μm' ,
    `create_by` VARCHAR(32)   COMMENT '创建人' ,
    `create_time` DATETIME   COMMENT '创建时间' ,
    `update_by` VARCHAR(32)   COMMENT '更新人' ,
    `update_time` DATETIME   COMMENT '更新时间' ,
    PRIMARY KEY (id)
)  COMMENT = '透过率表';

DROP TABLE IF EXISTS meas_data_results;
CREATE TABLE meas_data_results(
    `id` INT AUTO_INCREMENT COMMENT '编号' ,
    `measurement_batch_id` VARCHAR(255) NOT NULL  COMMENT '测量批次id' ,
    `spec_irr_1` VARCHAR(255)   COMMENT '光谱辐射强度3~5μm' ,
    `spec_irr_2` VARCHAR(255)   COMMENT '光谱辐射强度8~14μm' ,
    `spec_band_irr_1` DECIMAL(8,2)   COMMENT '波段辐射强度3~5μm' ,
    `spec_band_irr_2` DECIMAL(8,2)   COMMENT '波段辐射强度8~14μm' ,
    `create_by` VARCHAR(32)   COMMENT '创建人' ,
    `create_time` DATETIME   COMMENT '创建时间' ,
    `update_by` VARCHAR(32)   COMMENT '更新人' ,
    `update_time` DATETIME   COMMENT '更新时间' ,
    PRIMARY KEY (id)
)  COMMENT = '数据结果表';

